@@ -61,7 +61,7 @@
 #' inst$eval_batch(xdt)
 #'
 #' # Get archive data
-#' inst$archive$data()
+#' as.data.table(inst$archive)
 FSelectInstanceSingleCrit = R6Class("FSelectInstanceSingleCrit",
   inherit = OptimInstanceSingleCrit,
   public = list(
@@ -81,8 +81,6 @@ FSelectInstanceSingleCrit = R6Class("FSelectInstanceSingleCrit",
       self$objective$archive = self$archive
 
       private$.objective_function = objective_function
-      private$.objective_multiplicator =
-        ifelse(self$objective$codomain$tags == "minimize", 1, -1)
     },
 
     #' @description
@@ -112,6 +110,6 @@ objective_function = function(x, inst, multiplicator) {
   inst$search_space$assert(xs)
   xdt = as.data.table(xs)
   res = inst$eval_batch(xdt)
-  y = as.numeric(res[, inst$objective$codomain$ids(), with = FALSE])
+  y = as.numeric(res[, inst$archive$cols_y, with = FALSE])
   y * multiplicator
 }
